%global pypi_version 24.7
%global pypi_name virt_firmware

Name:           python-virt-firmware
Version:        %{pypi_version}
Release:        %mkrel 2
Summary:        Tools for virtual machine firmware volumes
Group:          Development/Python
License:        GPLv2
URL:            https://pypi.org/project/virt-firmware/
Source0:        %{pypi_source}
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  make help2man

%description
Tools for ovmf / armvirt firmware volumes This is a small collection of tools
for edk2 firmware images. They support decoding and printing the content of
firmware volumes. Variable stores (OVMF_VARS.fd) can be modified, for example
to enroll secure boot certificates.

%package -n     python3-virt-firmware
Summary:        %{summary}
%{?python_provide:%python_provide python3-virt-firmware}
Provides:       virt-firmware
%description -n python3-virt-firmware
Tools for ovmf / armvirt firmware volumes This is a small collection of tools
for edk2 firmware images. They support decoding and printing the content of
firmware volumes. Variable stores (OVMF_VARS.fd) can be modified, for example
to enroll secure boot certificates.

%package -n     python3-virt-firmware-peutils
Summary:        %{summary} - peutils
Conflicts:      python3-virt-firmware < 1.6
%description -n python3-virt-firmware-peutils
Some utilities to inspect efi (pe) binaries.

%package -n     python3-virt-firmware-tests
Summary:        %{summary} - test cases
Requires:       python3-virt-firmware
Requires:       python3dist(pytest)
Requires:       edk2-ovmf
%description -n python3-virt-firmware-tests
test cases

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

rm experimental/filter-sigdb.jq

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install

# manpages
install -m 755 -d      %{buildroot}%{_mandir}/man1
install -m 644 man/*.1 %{buildroot}%{_mandir}/man1
# tests
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -ar tests %{buildroot}%{_datadir}/%{name}

%files -n python3-virt-firmware
%license LICENSE
%doc README.md experimental
%{_bindir}/host-efi-vars
%{_bindir}/virt-fw-dump
%{_bindir}/virt-fw-vars
%{_bindir}/virt-fw-sigdb
%{_bindir}/kernel-bootcfg
%{_bindir}/uefi-boot-menu
%{_bindir}/migrate-vars
%{_bindir}/pe-inspect
%{_mandir}/man1/virt-*.1*
%{_mandir}/man1/kernel-bootcfg.1.xz
%{_mandir}/man1/pe-inspect.1.xz
%{_mandir}/man1/uefi-boot-menu.1.xz
%{python3_sitelib}/virt/firmware
%{python3_sitelib}/virt_firmware-*.dist-info

%files -n python3-virt-firmware-peutils
%{python3_sitelib}/virt/peutils
%{_bindir}/pe-dumpinfo
%{_bindir}/pe-listsigs
%{_bindir}/pe-addsigs

%files -n python3-virt-firmware-tests
%{_datadir}/%{name}/tests



%changelog
* Fri Dec 27 2024 daviddavid <daviddavid> 24.7-2.mga10
+ Revision: 2130683
- drop unwanted experimental filter-sigdb.jq file

* Sun Nov 24 2024 papoteur <papoteur> 24.7-1.mga10
+ Revision: 2118748
- update to 24.7
- rebuild for python 3.12
- use pyproject macros and generate BR
- add pe-inspect command

* Sat Sep 16 2023 tv <tv> 23.6-1.mga10
+ Revision: 1987118
- Update to version 23.6

* Fri Dec 02 2022 tv <tv> 1.7-1.mga9
+ Revision: 1915096
- Update to version 1.7
- Split peutils to subpackage
- Add man-pages
- Add tests sub-package

* Wed Jun 22 2022 tv <tv> 0.98-1.mga9
+ Revision: 1865443
- imported package python-virt-firmware


* Tue May 24 2022 Gerd Hoffmann <kraxel@redhat.com> - 0.98-1
- update to version 0.98

* Mon Apr 11 2022 Gerd Hoffmann <kraxel@redhat.com> - 0.95-1
- Initial package.
